"""

A setuptools based setup module.
See:
https://packaging.python.org/en/latest/distributing.html
https://github.com/pypa/sampleproject

"""

# Always prefer setuptools over distutils
from setuptools import setup, find_packages
from setuptools.command.develop import develop
from setuptools.command.install import install
from setuptools.command.test import test as TestCommand

# To use a consistent encoding
from codecs import open
from os import path, system

here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(here, 'README.rst'), encoding='utf-8') as f:
    long_description = f.read()


class PostDevelopCommand(develop):
    """Post-installation for development mode."""
    def run(self):
        print("TODO: PostDevelopCommand")
        develop.run(self)


class PostInstallCommand(install):
    """Post-installation for installation mode."""
    def run(self):
        print("TODO: PostInstallCommand")
        install.run(self)


class Tox(TestCommand):
    user_options = [('tox-args=', 'a', "Arguments to pass to tox")]
    def initialize_options(self):
        TestCommand.initialize_options(self)
        self.tox_args = None
    def finalize_options(self):
        TestCommand.finalize_options(self)
        self.test_args = []
        self.test_suite = True
    def run_tests(self):
        #import here, cause outside the eggs aren't loaded
        import tox
        import shlex
        args = self.tox_args
        if args:
            args = shlex.split(self.tox_args)
        tox.cmdline(args=args)

setup(
    name='allocator',

    # Versions should comply with PEP440.  For a discussion on single-sourcing
    # the version across setup.py and the project code, see
    # https://packaging.python.org/en/latest/single_source_version.html
    version='0.1.7',

    description='Optimally Allocate Geographically Distributed Tasks',
    long_description=long_description,

    # The project's main homepage.
    url='https://github.com/soodoku/allocator',

    # Author details
    author='Suriyan Laohaprapanon, Gaurav Sood',
    author_email='suriyant@gmail.com, gsood07@gmail.com',

    # Choose your license
    license='MIT',

    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 3 - Alpha',

        # Indicate who your project is intended for
        'Intended Audience :: Developers',

        # Pick your license as you wish (should match "license" above)
        'License :: OSI Approved :: MIT License',

        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.5',
        'Topic :: Scientific/Engineering :: Information Analysis',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Utilities'
    ],

    # What does your project relate to?
    keywords='routing shortest path',

    # You can just specify the packages manually here if your project is
    # simple. Or you can use find_packages().
    packages=find_packages(exclude=['data', 'docs', 'tests', 'scripts']),

    # Alternatively, if you want to distribute just a my_module.py, uncomment
    # this:
    #   py_modules=["my_module"],

    # List run-time dependencies here.  These will be installed by pip when
    # your project is installed. For an analysis of "install_requires" vs pip's
    # requirements files see:
    # https://packaging.python.org/en/latest/requirements.html
    install_requires=[
        'pandas>=0.19.2',
        'numpy>=1.12.1',
        'matplotlib>=1.5.1',
        'utm>=0.4.0',
        'networkx',
        'googlemaps',
        'polyline',
        'haversine',
        'folium',
        'scipy'
    ],

    # List additional groups of dependencies here (e.g. development
    # dependencies). You can install these using the following syntax,
    # for example:
    # $ pip install -e .[dev,test]
    extras_require={
        'dev': ['check-manifest'],
        'test': ['coverage'],
    },

    # If there are data files included in your packages that need to be
    # installed, specify them here.  If using Python 2.6 or less, then these
    # have to be included in MANIFEST.in as well.
    package_data={
        'allocator': ['examples/*.csv',
                      'examples/*.png',
                      'examples/sort-by-distance/*.csv',
                      'examples/sort-by-distance/*.png',
                      'examples/kmeans/*.csv',
                      'examples/kmeans/*.png',
                      'examples/KaHIP/*.csv',
                      'examples/KaHIP/*.png',
                      'examples/TSP-buffoon/*.svg',
                      'examples/TSP-kmeans/*.svg',
                      'examples/TSP-ortools-kmeans/*.png',
                      'examples/TSP-ortools-kmeans/map/*.html',
                      'examples/TSP-ortools-buffoon/delhi/*.png',
                      'examples/TSP-ortools-buffoon/chonburi/*.png',
                      'examples/GM-buffoon/chonburi/*.png',
                      'examples/GM-buffoon/delhi/*.png',
                      'examples/OSRM-buffoon/*.html',
                      'examples/compare-kahip-kmeans/*.csv',
                      'tests/*.csv',
                      ],
    },

    # Although 'package_data' is the preferred approach, in some case you may
    # need to place data files outside of your packages. See:
    # http://docs.python.org/3.4/distutils/setupscript.html#installing-additional-files # noqa
    # In this case, 'ethnicolr' will be installed into '<sys.prefix>/ethnicolr'

    #data_files=[('ethnicolr', ['ethnicolr/data/test.txt'])],

    # To provide executable scripts, use entry points in preference to the
    # "scripts" keyword. Entry points provide cross-platform support and allow
    # pip to create the appropriate form of executable for the target platform.
    entry_points={
        'console_scripts': [
            'sort_by_distance=allocator.sort_by_distance:main',
            'cluster_kmeans=allocator.cluster_kmeans:main',
            'cluster_kahip=allocator.cluster_kahip:main',
            'shortest_path_mst_tsp=allocator.shortest_path_mst_tsp:main',
            'shortest_path_ortools=allocator.shortest_path_ortools:main',
            'shortest_path_gm=allocator.shortest_path_gm:main',
            'shortest_path_osrm=allocator.shortest_path_osrm:main',
            'compare_kahip_kmeans=allocator.compare_kahip_kmeans:main',
        ],
    },
    cmdclass={
        'develop': PostDevelopCommand,
        'install': PostInstallCommand,
        'test': Tox,
    },
    tests_require=['tox'],
)
